summaryrefslogtreecommitdiff
path: root/noncore/settings/tabmanager/tabmanager.cpp
Side-by-side diff
Diffstat (limited to 'noncore/settings/tabmanager/tabmanager.cpp') (more/less context) (show whitespace changes)
-rw-r--r--noncore/settings/tabmanager/tabmanager.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/noncore/settings/tabmanager/tabmanager.cpp b/noncore/settings/tabmanager/tabmanager.cpp
index c9d7aed..ff5957c 100644
--- a/noncore/settings/tabmanager/tabmanager.cpp
+++ b/noncore/settings/tabmanager/tabmanager.cpp
@@ -190,3 +190,3 @@ void TabManager::removeItem(){
- bool removeSuccessfull = true;
+ bool removeSuccessful = true;
QString location = itemList[item];
@@ -194,3 +194,3 @@ void TabManager::removeItem(){
if(!QFile::remove(location))
- removeSuccessfull = false;
+ removeSuccessful = false;
@@ -202,5 +202,5 @@ void TabManager::removeItem(){
if(!dir.rmdir(location))
- removeSuccessfull = false;
+ removeSuccessful = false;
else
- removeSuccessfull = true;
+ removeSuccessful = true;
}
@@ -208,3 +208,3 @@ void TabManager::removeItem(){
// If removing failed.
- if(!removeSuccessfull){
+ if(!removeSuccessful){
qDebug((QString("removeItem: ") + location).latin1());
@@ -438,3 +438,3 @@ void TabManager::moveApplication(QListViewItem *item, QListViewItem *newGroup){
* @param installedAppFile - location of the app install list
* @return true if successfull, false if file not found.
*/
@@ -438,3 +438,3 @@ void TabManager::moveApplication(QListViewItem *item, QListViewItem *newGroup){
* @param installedAppFile - location of the app install list
- * @return true if successfull, false if file not found.
+ * @return true if successful, false if file not found.
*/